@@ -6,8 +6,12 @@ summary(sfa(log( output ) ~ log( capital ) + log( labour ), data=front41Data))
 summary(spfrontier(log( output ) ~ log( capital ) + log( labour ), data=front41Data))
 
 
-summary(sfa(log( output ) ~ log( capital ) + log( labour ), data=front41Data, truncNorm=T))
-summary(spfrontier(log( output ) ~ log( capital ) + log( labour ), data=front41Data, inefficiency="truncated"))
+sfa <- sfa(log( output ) ~ log( capital ) + log( labour ), data=front41Data, truncNorm=T)
+summary(sfa)
+ssf <- spfrontier(log( output ) ~ log( capital ) + log( labour ), data=front41Data, inefficiency="truncated")
+summary(ssf)
+
+logLikelihood(log( output ) ~ log( capital ) + log( labour ), data=front41Data, inefficiency="truncated",values=c(0.46453,0.28327,0.54098,0.22762,0.91568,-2.84150))
 
 mu <- seq(-3,0, by=0.01)
 sigma<- seq(0.3,1, by=0.01)
@@ -16,7 +20,7 @@ i<-1
 j<-1
 for(m in mu){
     for(s in sigma){
-        z[i,j]<-logLikelihood(log( output ) ~ log( capital ) + log( labour ), data=front41Data, inefficiency="truncated",values=c(0.46553,0.28320,0.54096,0.22744,s,m))
+        z[i,j]<-logLikelihood(log( output ) ~ log( capital ) + log( labour ), data=front41Data, inefficiency="truncated",values=c(0.46453,0.28327,0.54098,0.22762,s,m))
         j <- j + 1
     }
     i <- i + 1
